import { get } from 'lodash';
import kyUniversal from 'ky-universal';
/** Variable to store the last returned config
 *
 * @interface IConfig
 */
let lastReturnedConfig;
/**
 * Tries to retrieve an endpoint configuration from the site root configuration file
 * Every eva-suite hosted deployment can have a config file which details which
 * backend server to use.
 * Development installation will often not have this file to fallback on a
 * selection mechanism from the customer manager
 *
 * @returns {(Promise<IConfig|undefined>)}
 */
export const getConfigFromRootConfig = async () => {
    // Return the lastReturnedConfig if it's available
    // If it is not available it will be set below
    //
    if (lastReturnedConfig) {
        return lastReturnedConfig;
    }
    // There is a special EVA config loader for pre-application availability of the
    // config for analytics and such
    // We can check its existence here to prevent duplicate retrieval
    //
    const evaConfigLoaderConfig = get(window, 'eva_config_loader.config');
    if (evaConfigLoaderConfig) {
        lastReturnedConfig = evaConfigLoaderConfig;
        return evaConfigLoaderConfig;
    }
    const evaConfigLoaderStatus = get(window, 'eva_config_loader.status');
    if (evaConfigLoaderStatus === 'NOT_FOUND') {
        return;
    }
    // If this is a customer specific deployment we will
    // be able to get the URL from the config.json on / (root level)
    //
    const configFileUrl = '/eva-config.json';
    console.log(`[EVA-CONTEXT] fetch config info: ${configFileUrl}`);
    try {
        const evaConfigInfo = await kyUniversal.get(configFileUrl).json();
        lastReturnedConfig = evaConfigInfo;
        console.log(`[EVA-CONTEXT] fetched config info: ${evaConfigInfo}`);
        return evaConfigInfo;
    }
    catch (fetchConfigInfoError) {
        console.warn('[EVA-CONTEXT] failed to fetch config info for app', fetchConfigInfoError);
    }
};
//# sourceMappingURL=config.js.map